---
name: Bug report
about: Something isn't working as expected
title: ''
labels: bug
assignees: ''

---


## Prerequisites
Please make sure to check off these prerequisites before submitting a bug report.
- [ ] Test that the bug appears on the current version of the master branch. Make sure to include the commit hash of the commit you checked out.
- [ ] Check that the issue hasn't already been reported, by checking the currently open issues.
- [ ] If there are steps to reproduce the problem, make sure to write them down below.
- [ ] If relevant, please include the hls4ml project files, which were created directly before and/or after the bug.

## Quick summary
Please give a brief and concise description of the bug.

## Details
Please add to the following sections to describe the bug as accurately as possible.

### Steps to Reproduce
Add what needs to be done to reproduce the bug. Add *commented* code examples and make sure to include the original model files / code, and the commit hash you are working on.

1. Clone the hls4ml repository
2. Checkout the master branch, with commit hash: [...]
3. Run conversion [...] on model file with code [...]
4. [Further steps ...]

### Expected behavior
Please add a brief description of what you expected to happen.

### Actual behavior
Describe what actually happens instead.

## Optional

### Possible fix
If you already know where the issue stems from, or you have a hint please let us know.

### Additional context
Add any other context about the problem here.
